<h1>Eureka Connection</h1>


<h2>Enviroment variables:</h2>
  'PROTOCOL': Protocol of comunication with discovery service (Optional)<br>
  'HOSTDISCOVER': Host of Discovery Service<br>
  'PORTDISCOVER': Port of Discovery Service (Optional)<br>
  'SERVICENAME': Name or service registering to discovery service<br>
  'HOSTINSTANCE': Host of instance holding service (Optional)<br>
  'PORTINSTANCE': Port of instance holding service (Optional)<br>
  'HEARTBEATDISCOVER': Hearth beat for notice to discovery service (Optional)<br>
